@@ -10,8 +10,9 @@ from requests_toolbelt.multipart.encoder import MultipartEncoder
 
 from .common import PersonSettingsApiChild
 from ..base import ApiModel
+from ..common import Greeting
 
-__all__ = ['VoicemailApi', 'VoicemailEnabled', 'Greeting', 'VoicemailEnabledWithGreeting', 'UnansweredCalls',
+__all__ = ['VoicemailApi', 'VoicemailEnabled', 'VoicemailEnabledWithGreeting', 'UnansweredCalls',
            'StorageType', 'VoicemailMessageStorage', 'VoicemailCopyOfMessage', 'VoicemailFax',
            'VoicemailTransferToNumber', 'VoicemailNotifications', 'VoiceMailFax', 'VoicemailSettings']
 
@@ -20,16 +21,6 @@ class VoicemailEnabled(ApiModel):
     enabled: bool
 
 
-class Greeting(str, Enum):
-    """
-    Greeting type
-    """
-    #: The default greeting will be played.
-    default = 'DEFAULT'
-    #: Designates that a custom .wav file will be played.
-    custom = 'CUSTOM'
-
-
 class VoicemailEnabledWithGreeting(VoicemailEnabled):
     """
     Voicemail enablement setting with greeting details
